==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AzureActiveDirectoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active directory provider.
 * @property enabled <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
 * @property isAutoProvisioned Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
 * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
 * read or write to this property.
 * @property login The configuration settings of the Azure Active Directory login flow.
 * @property registration The configuration settings of the Azure Active Directory app registration.
 * @property validation The configuration settings of the Azure Active Directory token validation flow.
 */
public data class AzureActiveDirectoryArgs(
    public val enabled: Output<Boolean>? = null,
    public val isAutoProvisioned: Output<Boolean>? = null,
    public val login: Output<AzureActiveDirectoryLoginArgs>? = null,
    public val registration: Output<AzureActiveDirectoryRegistrationArgs>? = null,
    public val validation: Output<AzureActiveDirectoryValidationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs =
        com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .isAutoProvisioned(isAutoProvisioned?.applyValue({ args0 -> args0 }))
            .login(login?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .registration(registration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .validation(validation?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AzureActiveDirectoryArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var isAutoProvisioned: Output<Boolean>? = null

    private var login: Output<AzureActiveDirectoryLoginArgs>? = null

    private var registration: Output<AzureActiveDirectoryRegistrationArgs>? = null

    private var validation: Output<AzureActiveDirectoryValidationArgs>? = null

    /**
     * @param value <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
     */
    @JvmName("qihrvmbvekjhgtro")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
     * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
     * read or write to this property.
     */
    @JvmName("mnfehkkatrcqyugb")
    public suspend fun isAutoProvisioned(`value`: Output<Boolean>) {
        this.isAutoProvisioned = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("iilkitiaynohtlaf")
    public suspend fun login(`value`: Output<AzureActiveDirectoryLoginArgs>) {
        this.login = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("ntenwecfnvebesei")
    public suspend fun registration(`value`: Output<AzureActiveDirectoryRegistrationArgs>) {
        this.registration = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("lplgiiuonilsicgt")
    public suspend fun validation(`value`: Output<AzureActiveDirectoryValidationArgs>) {
        this.validation = value
    }

    /**
     * @param value <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
     */
    @JvmName("vkdsbjiqsrxqyrup")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
     * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
     * read or write to this property.
     */
    @JvmName("bkkanuhvyknctdym")
    public suspend fun isAutoProvisioned(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoProvisioned = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("aqlxhrtewpcnilxq")
    public suspend fun login(`value`: AzureActiveDirectoryLoginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.login = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("svbdjknegdxrveal")
    public suspend fun login(argument: suspend AzureActiveDirectoryLoginArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryLoginArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.login = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("xpdxccqrvfaxsnaq")
    public suspend fun registration(`value`: AzureActiveDirectoryRegistrationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registration = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("wqqrovfyhcujkeve")
    public suspend
    fun registration(argument: suspend AzureActiveDirectoryRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryRegistrationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.registration = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("rbeydewtqsfwifie")
    public suspend fun validation(`value`: AzureActiveDirectoryValidationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validation = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("ffjasfwifcnmetdg")
    public suspend
    fun validation(argument: suspend AzureActiveDirectoryValidationArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryValidationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.validation = mapped
    }

    internal fun build(): AzureActiveDirectoryArgs = AzureActiveDirectoryArgs(
        enabled = enabled,
        isAutoProvisioned = isAutoProvisioned,
        login = login,
        registration = registration,
        validation = validation,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AzureActiveDirectoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active directory provider.
 * @property enabled <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
 * @property isAutoProvisioned Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
 * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
 * read or write to this property.
 * @property login The configuration settings of the Azure Active Directory login flow.
 * @property registration The configuration settings of the Azure Active Directory app registration.
 * @property validation The configuration settings of the Azure Active Directory token validation flow.
 */
public data class AzureActiveDirectoryArgs(
    public val enabled: Output<Boolean>? = null,
    public val isAutoProvisioned: Output<Boolean>? = null,
    public val login: Output<AzureActiveDirectoryLoginArgs>? = null,
    public val registration: Output<AzureActiveDirectoryRegistrationArgs>? = null,
    public val validation: Output<AzureActiveDirectoryValidationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs =
        com.pulumi.azurenative.web.inputs.AzureActiveDirectoryArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .isAutoProvisioned(isAutoProvisioned?.applyValue({ args0 -> args0 }))
            .login(login?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .registration(registration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .validation(validation?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AzureActiveDirectoryArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var isAutoProvisioned: Output<Boolean>? = null

    private var login: Output<AzureActiveDirectoryLoginArgs>? = null

    private var registration: Output<AzureActiveDirectoryRegistrationArgs>? = null

    private var validation: Output<AzureActiveDirectoryValidationArgs>? = null

    /**
     * @param value <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
     */
    @JvmName("ltfmnxhidlpsfitg")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
     * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
     * read or write to this property.
     */
    @JvmName("bfjjnhyyudvlhrxm")
    public suspend fun isAutoProvisioned(`value`: Output<Boolean>) {
        this.isAutoProvisioned = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("gvvvmelhpmjtfuou")
    public suspend fun login(`value`: Output<AzureActiveDirectoryLoginArgs>) {
        this.login = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("ujjslvyhyxidwhjh")
    public suspend fun registration(`value`: Output<AzureActiveDirectoryRegistrationArgs>) {
        this.registration = value
    }

    /**
     * @param value The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("suvpshjujffphvkg")
    public suspend fun validation(`value`: Output<AzureActiveDirectoryValidationArgs>) {
        this.validation = value
    }

    /**
     * @param value <code>false</code> if the Azure Active Directory provider should not be enabled despite the set registration; otherwise, <code>true</code>.
     */
    @JvmName("wowmbnsekvosddbq")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Gets a value indicating whether the Azure AD configuration was auto-provisioned using 1st party tooling.
     * This is an internal flag primarily intended to support the Azure Management Portal. Users should not
     * read or write to this property.
     */
    @JvmName("kkcampmfkrqeuate")
    public suspend fun isAutoProvisioned(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoProvisioned = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("audqdqxmjjchrkqc")
    public suspend fun login(`value`: AzureActiveDirectoryLoginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.login = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory login flow.
     */
    @JvmName("mpqbcmngspovfquw")
    public suspend fun login(argument: suspend AzureActiveDirectoryLoginArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryLoginArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.login = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("jtcoprghwhuauxvr")
    public suspend fun registration(`value`: AzureActiveDirectoryRegistrationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registration = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory app registration.
     */
    @JvmName("vqqnpvumvngibaxs")
    public suspend
    fun registration(argument: suspend AzureActiveDirectoryRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryRegistrationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.registration = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("gydfrcuwvbbpniuu")
    public suspend fun validation(`value`: AzureActiveDirectoryValidationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validation = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active Directory token validation flow.
     */
    @JvmName("cxkmcaybilrnordr")
    public suspend
    fun validation(argument: suspend AzureActiveDirectoryValidationArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryValidationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.validation = mapped
    }

    internal fun build(): AzureActiveDirectoryArgs = AzureActiveDirectoryArgs(
        enabled = enabled,
        isAutoProvisioned = isAutoProvisioned,
        login = login,
        registration = registration,
        validation = validation,
    )
}
